# Installation
- Require python >= 3.10
- using pip
    ```
    $ pip install coca-tools
    ```
- using poetry
    ```
    $ poetry add coca-tools
    ```


# Guide
- Require: using in global environment
- create fastapi template with command then fill the questions
    ```
    $ create-fastapi-app
    ```
- create django template with command then fill the questions
    ```
    $ create-django-app
    ```
